@@ -4,7 +4,12 @@ sub p() {
     return 5;
 };
 
+# To have something to "step different" with.
 my $x=1; my $y=2; 
 $x=$y; $y = 4; $x += $y;
 $x=6; $y = p(); my $z = p(); 
-$x = 8 + $y + $z;
+
+# To have something to "step" with
+$x = 8;
+$x += $y;
+$x += $z;
