@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rockb@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rockb@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 
@@ -13,7 +13,14 @@ use vars qw(@ISA @SUBCMD_VARS);
 # Values inherited from parent
 use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
-our $HELP = "Show the value about to be returned";
+our $SHORT_HELP = "Show the value about to be returned";
+our $HELP = <<'HELP';
+=pod
+
+Show the value about to be returned.
+=cut
+HELP
+
 our $MIN_ABBREV = length('ret');
 use constant NEED_STACK => 1;
 
@@ -25,19 +32,19 @@ sub run($$)
     my $proc = $self->{proc};
 
     unless ($DB::event eq 'return') {
-	$proc->errmsg("We are not stopped at a return");
-	return;
+        $proc->errmsg("We are not stopped at a return");
+        return;
     }
     my $ret_type = $proc->{dbgr}->return_type();
     if ('undef' eq $ret_type) {
-	$proc->msg("Return value for $DB::_[0] is <undef>");
+        $proc->msg("Return value for $DB::_[0] is <undef>");
     } elsif ('array' eq $ret_type) {
-	$proc->msg("Return array value for $DB::_[0] is:");
-	my @ret = $proc->{dbgr}->return_value();
-	$proc->msg(Dumper(@ret));
+        $proc->msg("Return array value for $DB::_[0] is:");
+        my @ret = $proc->{dbgr}->return_value();
+        $proc->msg(Dumper(@ret));
     } elsif ('scalar' eq $ret_type) {
-	my $ret = $proc->{dbgr}->return_value() || 'undef';
-	$proc->msg("Return value for $DB::_[0] is: $ret");
+        my $ret = $proc->{dbgr}->return_value() || 'undef';
+        $proc->msg("Return value for $DB::_[0] is: $ret");
     }
 }
 
