@@ -26,42 +26,43 @@ use vars qw(@ISA); @ISA = @CMD_ISA;
 use vars @CMD_VARS;  # Value inherited from parent
 
 $NAME = set_name();
-$HELP = <<"HELP";
-${NAME}[+|-] [into] [count]
-${NAME} until EXPRESSION
-${NAME} thread
-${NAME} to METHOD-NAME
-${NAME} over 
-${NAME} out
+$HELP = <<'HELP';
+=pod
+
+step[+|-] [into] [I<count>]
+
+step over 
+
+step out
 
 Execute the current line, stopping at the next event.  Sometimes this
-is called 'step into'.
+is called "step into".
 
 With an integer argument, step that many times.  With an 'until'
 expression that expression is evaluated and we stop the first time it
 is true.
 
-A suffix of '+' in a command or an alias forces a move to another
-position, while a suffix of '-' disables this requirement.  A suffix
-of '>' will continue until the next call. ('finish' will run run until
+A suffix of C<+> in a command or an alias forces a move to another
+position, while a suffix of C<-> disables this requirement.  A suffix
+of C<E<gt>> will continue until the next call. (C<finish> will run run until
 the return for that call.)
 
-If no suffix is given, the debugger setting 'different' determines
+If no suffix is given, the debugger setting C<different> determines
 this behavior.
 
-Examples: 
-  ${NAME}        # step 1 event, *any* event obeying 'set different' setting
-  ${NAME} 1      # same as above
-  ${NAME}+       # same but force stopping on a new line
-  ${NAME}-       # same but force stopping on a new line a new frame added
-  ${NAME} until a > b
-  ${NAME} over   # same as 'next'
-  ${NAME} out    # same as 'finish'
-  ${NAME} thread # step stopping only in the current thread. Is the same
-                 # as step until Thread.current.object_id == #object_id
+=head2 Examples: 
 
-Related and similar is the 'next' (step over) and 'finish' (step out)
-commands.  All of these are slower than running to a breakpoint.
+ step        # step 1 event, any event obeying 'set different' setting
+ step 1      # same as above
+ step+       # same but force stopping on a new line
+ step-       # same but force stopping on a new line a new frame added
+ step over   # same as 'next'
+ step out    # same as 'finish'
+
+Related and similar is the C<next> (step over) and C<finish> (step out)
+commands. All of these are slower than running to a breakpoint. See also
+C<set different>.
+=cut
 HELP
 
 my $Keyword_to_related_cmd = {
@@ -80,13 +81,13 @@ sub run($$) {
     my $opts = $proc->parse_next_step_suffix($args->[0]);
     # condition = nil
     if (0 == $#$args) {
-	# Form is: "step" which means "step 1"
-	$proc->{skip_count} = 0;
+        # Form is: "step" which means "step 1"
+        $proc->{skip_count} = 0;
     } else {
-	my $replace_cmd = $Keyword_to_related_cmd->{$args->[1]};
-	if (defined($replace_cmd)) {
-	    my $cmd = $proc->{commands}{$replace_cmd};
-	    return $cmd->run( ($replace_cmd, splice(@$args, 2)) );
+        my $replace_cmd = $Keyword_to_related_cmd->{$args->[1]};
+        if (defined($replace_cmd)) {
+            my $cmd = $proc->{commands}{$replace_cmd};
+            return $cmd->run( ($replace_cmd, splice(@$args, 2)) );
     #   } elsif ('until' eq $args->[1]) {
     #     my $try_condition = join(@$args[2..-1], ' ');
     #     if (valid_condition?(try_condition)) {
@@ -110,19 +111,19 @@ sub run($$) {
     #     $condition = "Thread.current.object_id == ${Thread.current.object_id}"
     #     $opts[:different_pos] = 0;
     #     $proc->{skip_count] = 0;
-	} else {
-	    my $count_str = $args->[1];
-	    my $int_opts = {
-		msg_on_error => 
-		    "The 'step' command argument must eval to an integer. Got: ${count_str}",
-		    min_value => 1
-	    };
-	    #     }.merge(opts)
-	    my $count = $proc->get_an_int($count_str, $int_opts);
-	    return unless defined($count);
-	    # step 1 is $proc->{skip_count} = 0 or "stop next event"
-	    $proc->{skip_count} = $count - 1  ;
-	}
+        } else {
+            my $count_str = $args->[1];
+            my $int_opts = {
+                msg_on_error => 
+                    "The 'step' command argument must eval to an integer. Got: ${count_str}",
+                    min_value => 1
+            };
+            #     }.merge(opts)
+            my $count = $proc->get_an_int($count_str, $int_opts);
+            return unless defined($count);
+            # step 1 is $proc->{skip_count} = 0 or "stop next event"
+            $proc->{skip_count} = $count - 1  ;
+        }
     }
     $proc->step($opts)
 }
