@@ -176,7 +176,7 @@ sub read_command($;$) {
     my $last = $self->readline($prompt);
     my $line = '';
     $prompt .= '>> '; # continuation
-    while ('\\' eq substr($last, -1)) { 
+    while ($last && '\\' eq substr($last, -1)) { 
         $line .= substr($last, 0, -1) . "\n";
         $last = $self->readline($prompt);
     }
